@@ -21,8 +21,8 @@ library(Rsamtools)
 ###################################################
 ### code chunk number 4: ScanBamParam
 ###################################################
-which <- RangesList(seq1=IRanges(1000, 2000),
-                    seq2=IRanges(c(100, 1000), c(1000, 2000)))
+which <- IRangesList(seq1=IRanges(1000, 2000),
+                     seq2=IRanges(c(100, 1000), c(1000, 2000)))
 what <- c("rname", "strand", "pos", "qwidth", "seq")
 param <- ScanBamParam(which=which, what=what)
 
@@ -88,7 +88,7 @@ list.files(dirname(bamFile), pattern="ex1.bam(.bai)?")
 ###################################################
 ### code chunk number 12: bam-remote (eval = FALSE)
 ###################################################
-## which <- RangesList("6"=IRanges(100000L, 110000L))
+## which <- IRangesList("6"=IRanges(100000L, 110000L))
 ## param <- ScanBamParam(which=which, what=scanBamWhat())
 ## na19240bam <- scanBam(na19240url, param=param)
 
