@@ -81,8 +81,8 @@ public:
 
     // constructor / destructor
     BamIterator(bamFile bfile, const bam_index_t *bindex) :
-        bindex(bindex), iter_done(false),
-        bam((bam1_t *) NULL), bam_data((BAM_DATA) NULL)
+        bam_data((BAM_DATA) NULL), bindex(bindex),
+        bam((bam1_t *) NULL), iter_done(false)
     {
         bam_seek(bfile, 0, 0);
         header = bam_header_read(bfile);
