@@ -2,12 +2,13 @@
 #define _BCFFILE_H_
 
 #include <Rdefines.h>
-#include "bcftools/bcf.h"
+#include <htslib/tbx.h>
+#include <htslib/vcf.h>
 
 /* io_bcf.c */
 typedef struct {
-    bcf_t *file;
-    bcf_idx_t *index;
+    htsFile *file;
+    hts_idx_t *index;
 } _BCF_FILE;
 
 #define BCFFILE(b) ((_BCF_FILE *) R_ExternalPtrAddr(b))
@@ -19,7 +20,7 @@ SEXP bcffile_isopen(SEXP ext);
 SEXP bcffile_isvcf(SEXP ext);
 
 SEXP scan_bcf_header(SEXP ext);
-SEXP scan_bcf(SEXP ext, SEXP space, SEXP typemap);
+SEXP scan_bcf(SEXP ext, SEXP regions, SEXP tmpl);
 
 SEXP as_bcf(SEXP file, SEXP dictionary, SEXP destination);
 SEXP index_bcf(SEXP file);
